@@ -8,6 +8,7 @@ import httpx
 
 from gfwapiclient.http import HTTPClient
 from gfwapiclient.resources import (
+    BulkDownloadResource,
     DatasetResource,
     EventResource,
     FourWingsResource,
@@ -31,17 +32,21 @@ class Client:
     for accessing GFW's data.
 
     For more details on the GFW API and available data, please refer to the
-    official documentation:
+    official Global Fishing Watch API documentation:
 
     See: https://globalfishingwatch.org/our-apis/documentation#introduction
 
     See: https://globalfishingwatch.org/our-apis/documentation#data-available
 
+    See: https://globalfishingwatch.org/our-apis/documentation#api-dataset
+
+    See: https://globalfishingwatch.org/our-apis/documentation#data-caveat
+
     Attributes:
         fourwings (FourWingsResource):
             Access to the 4Wings data API resources.
 
-         vessels (VesselResource):
+        vessels (VesselResource):
             Access to the Vessels data API resources.
 
         events (EventResource):
@@ -53,6 +58,9 @@ class Client:
         datasets (DatasetResource):
             Access to the datasets data resources.
 
+        bulk_downloads (BulkDownloadResource):
+            Access to the Bulk download API resources.
+
         references (ReferenceResource):
             Access to the reference data resources.
     """
@@ -62,6 +70,7 @@ class Client:
     _events: EventResource
     _insights: InsightResource
     _datasets: DatasetResource
+    _bulk_downloads: BulkDownloadResource
     _references: ReferenceResource
 
     def __init__(
@@ -148,7 +157,7 @@ class Client:
         """4Wings data API resource.
 
         Provides access to the 4Wings API resources, which allow users to retrieve
-        reports on fishing activity and SAR vessel detections.
+        reports on AIS apparent fishing effort, AIS vessel presence and SAR vessel detections.
 
         For more details on the 4Wings API, please refer to the official
         Global Fishing Watch API documentation:
@@ -243,6 +252,26 @@ class Client:
             self._datasets = DatasetResource(http_client=self._http_client)
         return self._datasets
 
+    @property
+    def bulk_downloads(self) -> BulkDownloadResource:
+        """Bulk download API resource.
+
+        Provides access to the Bulk Download API resources, which allow to
+        efficiently create, retrieve, and download bulk reports data and files.
+
+        For more details on the Bulk Download API, please refer to the official
+        Global Fishing Watch API documentation:
+
+        See: https://globalfishingwatch.org/our-apis/documentation#bulk-download-api
+
+        Returns:
+            BulkDownloadResource:
+                The bulk download resource instance.
+        """
+        if not hasattr(self, "_bulk_downloads"):
+            self._bulk_downloads = BulkDownloadResource(http_client=self._http_client)
+        return self._bulk_downloads
+
     @property
     def references(self) -> ReferenceResource:
         """References data API resource.
