@@ -1,5 +1,7 @@
 """Global Fishing Watch (GFW) API Python Client - Resources."""
 
+from gfwapiclient.resources.bulk_downloads import BulkDownloadResource
+from gfwapiclient.resources.datasets import DatasetResource
 from gfwapiclient.resources.events import EventResource
 from gfwapiclient.resources.fourwings import FourWingsResource
 from gfwapiclient.resources.insights import InsightResource
@@ -8,6 +10,8 @@ from gfwapiclient.resources.vessels import VesselResource
 
 
 __all__ = [
+    "BulkDownloadResource",
+    "DatasetResource",
     "EventResource",
     "FourWingsResource",
     "InsightResource",
